@@ -33,12 +33,15 @@ class Recipe(object):
         if 'phantomjs' not in binaries:
             url = self.options.get('phantomjs-url', None)
             if not url:
+                version = self.options.get('phantomjs-version', '1.7.0')
                 if sys.platform == 'linux2':
                     url = ('https://phantomjs.googlecode.com/'
-                       'files/phantomjs-1.6.1-linux-x86_64-dynamic.tar.bz2')
+                       'files/phantomjs-%s-linux-x86_64.tar.bz2'
+                       ) % version
                 elif sys.platform == 'darwin':
                     url = ('https://phantomjs.googlecode.com/'
-                        'files/phantomjs-1.6.1-macosx-static.zip')
+                        'files/phantomjs-%s-macosx.zip'
+                      ) % version
                 else:
                     raise RuntimeError('Please specify a phantomjs-url')
             self.download(url)
@@ -46,8 +49,9 @@ class Recipe(object):
             self.download(self.options.get('casperjs-url',
                             'https://github.com/n1k0/casperjs/tarball/0.6.10'))
 
-        self.options['eggs'] = 'gp.recipe.phantomjs'
+        binaries = self.get_binaries()
         self.options['arguments'] = repr(binaries)
+        self.options['eggs'] = 'gp.recipe.phantomjs'
         self.options['entry-points'] = '\n'.join([
             '%s=gp.recipe.phantomjs.script:main' % s for s in binaries
             ])
